package Two;

use Rope;

extends 'One';

prototyped (
	three => sub {
		return 100;
	}
);

1;
